@@ -86,10 +86,12 @@ struct DisplayProperties {
 	int width;
 	int height;
 	int offset;
+	int horiz_scale;
+	int vertical_scale;
 };
 
-#define HORIZ_SCALE 2
-#define VERTICAL_SCALE 3
+//#define HORIZ_SCALE 2
+//#define VERTICAL_SCALE 3
 #define SMALL_VFD_BYTE_SIZE 280*16/8
 #define SMALL_TALL_VFD_BYTE_SIZE 280*32/8
 #define LARGE_VFD_BYTE_SIZE 512*32/8
@@ -98,9 +100,9 @@ struct DisplayProperties {
 #define SMALL_TALL_VFD_IDX 1
 #define LARGE_VFD_IDX 2
 static struct DisplayProperties displays[] = {
-	{SMALL_VFD_BYTE_SIZE, 280, 16, 33},
-	{SMALL_TALL_VFD_BYTE_SIZE, 280, 32, 34},
-	{LARGE_VFD_BYTE_SIZE, 512, 32, 34}
+	{SMALL_VFD_BYTE_SIZE, 280, 16, 33, 2, 3},
+	{SMALL_TALL_VFD_BYTE_SIZE, 280, 32, 34, 2, 3},
+	{LARGE_VFD_BYTE_SIZE, 512, 32, 34, 1, 2}
 };
 static int display_idx = SMALL_VFD_IDX;
 
@@ -171,12 +173,15 @@ static void update_pixbuf(char *display)
     int rowstride, n_channels, i, j, k, l, m, bit, display_ptr;
     unsigned int nibble;
     guchar *pixels, *p, red, green, blue;
+    int horiz_scale, vertical_scale;
 
     my_printf("%s()\n", __PRETTY_FUNCTION__);
 
     rowstride = gdk_pixbuf_get_rowstride (pixbuf);
     pixels = gdk_pixbuf_get_pixels (pixbuf);
     n_channels = gdk_pixbuf_get_n_channels (pixbuf);
+    horiz_scale = displays[display_idx].horiz_scale;
+    vertical_scale = displays[display_idx].vertical_scale;
 
     display_ptr = 0;
     for (i=0; i<displays[display_idx].width; i++) { /* columns */
@@ -200,8 +205,8 @@ static void update_pixbuf(char *display)
           }
           /* scale */
 #if 1
-          for (l=i*HORIZ_SCALE; l<(i*HORIZ_SCALE)+HORIZ_SCALE; l++) {
-            for (m=((j*4)+k)*VERTICAL_SCALE; m<(((j*4)+k)*VERTICAL_SCALE)+VERTICAL_SCALE; m++) {
+          for (l=i*horiz_scale; l<(i*horiz_scale)+horiz_scale; l++) {
+            for (m=((j*4)+k)*vertical_scale; m<(((j*4)+k)*vertical_scale)+vertical_scale; m++) {
               p = pixels + m * rowstride + l * n_channels;
               p[0] = red;
               p[1] = green;
@@ -725,8 +730,8 @@ setup_display_properties(int bytes_length) {
         g_object_unref(G_OBJECT(pixbuf));
         
         pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB, FALSE, 8,
-                            displays[display_idx].width*HORIZ_SCALE,
-                            displays[display_idx].height*VERTICAL_SCALE);
+                            displays[display_idx].width*displays[display_idx].horiz_scale,
+                            displays[display_idx].height*displays[display_idx].vertical_scale);
     }
     my_printf("%s(%i): return\n", __PRETTY_FUNCTION__, bytes_length);
 }
@@ -1467,8 +1472,8 @@ gint main(gint argc, gchar *argv[])
 
     /* Create pixel buf */
     pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB, FALSE, 8,
-                            displays[display_idx].width*HORIZ_SCALE,
-                            displays[display_idx].height*VERTICAL_SCALE);
+                            displays[display_idx].width*displays[display_idx].horiz_scale,
+                            displays[display_idx].height*displays[display_idx].vertical_scale);
     screen = gtk_image_new_from_pixbuf(pixbuf);
 
     //gtk_container_add(GTK_CONTAINER(window), screen);
